@@ -25,6 +25,19 @@
       (eval code)
       (eval code (current-module))))
         
+;; Feature masks:
+(define droppable-feature 1)
+(define scores-disabled 2)
+
+(define (reset-features) (set-feature-word! 0))
+
+(define (set-features . feature-list)
+  (set-feature-word! (+ (get-feature-word)
+		       (apply + feature-list))))
+
+;; Sol.scm gets evaluated whenever game types are switched,
+;; this makes sure that the old settings are gone.
+(reset-features)
 
 ;; Constants:
 
@@ -65,8 +78,8 @@
   (reset-surface)
   (set! FLIP-COUNTER 0)
   (set! SLOTS 0)
-  (set! HORIZPOS (get-horiz-start))
-  (set! VERTPOS (get-vert-start))
+  (set! HORIZPOS 0)
+  (set! VERTPOS 0)
   (set! IN-GAME #f)
   (set! MOVE '())
   (set-statusbar-message " ")
@@ -220,9 +233,11 @@
 ; when the stock slot is empty than the waste slot will be flipped back
 ; onto the stock unless the flip limit has been reached.
 ; an optional forth argument indicates the number of cards to deal.
+; If the flip limit is negative, it is treated as infinite.
 (define (flip-stock stock-slot waste-slot flip-limit . rest)
   (if (empty-slot? stock-slot)
-      (and (< FLIP-COUNTER flip-limit)
+      (and (or (< flip-limit 0)
+	       (< FLIP-COUNTER flip-limit))
 	   (set! FLIP-COUNTER (+ 1 FLIP-COUNTER))
 	   (flip-deck stock-slot waste-slot))
       (or (let loop ((i (if (null? rest) 1 (car rest))))
@@ -257,7 +272,7 @@
   (caddr card))
 
 (define (get-suit card) 
-  (cadr card))
+      (cadr card))
 
 (define (get-color card)
   (cond ((eq? (get-suit card) club) black)
@@ -266,8 +281,8 @@
 	((eq? (get-suit card) diamond) red)
 	(#t (_"Unknown color"))))
 
-(define (get-value card) 
-  (car card))
+(define (get-value card)
+      (car card))
 
 ; slot procedures
 (define (get-cards slot-id)
@@ -483,12 +498,12 @@
 
 (define (get-and-increment-position)
   (let ((retval (list HORIZPOS VERTPOS)))
-    (set! HORIZPOS (+ HORIZPOS (get-horiz-offset)))
+    (set! HORIZPOS (+ HORIZPOS 1))
     retval))
 
 (define (linefeed-position)
-  (set! HORIZPOS (get-horiz-start))
-  (set! VERTPOS (+ VERTPOS (get-vert-offset))))
+  (set! HORIZPOS 0)
+  (set! VERTPOS (+ VERTPOS 1)))
 
 (define (register-undo-function function data)
   (set! MOVE (cons '(function data) (cdr MOVE))))
