@@ -2,7 +2,7 @@
 
 /* gnome-stones - preferences.h
  *
- * Time-stamp: <2003-08-02 04:29:58 callum>
+ * Time-stamp: <2004/07/18 16:12:47 callum>
  *
  * Copyright (C) 1998, 2003 Carsten Schaar
  *
@@ -37,7 +37,6 @@
 
 #include "sound.h"
 
-#define KEY_SCROLL_METHOD "/apps/gnome-stones/preferences/scroll_method"
 #define KEY_GAME_NAME "/apps/gnome-stones/preferences/game_name"
 #define KEY_START_CAVE "/apps/gnome-stones/preferences/start_cave"
 #define KEY_JOYSTICK_DEVICE "/apps/gnome-stones/preferences/joystick_device"
@@ -93,11 +92,6 @@ guint start_cave= 0;
 gfloat   joystick_switch_level= 0.5;
 
 
-/* This is default scroll method for view function */
-
-void (*view_scroll_method) (GStonesView *view, GStonesCave *cave)= atari_scroll;
-
-
 /* The game can be in different states.  These state decides, how to
    react if some events occur.  */
 
@@ -240,52 +234,10 @@ load_game_by_name (const char *filename, guint cave)
   return FALSE;
 }
 
-
-
-/*****************************************************************************/
-/* string<-->scroll_method conversion  */
-
-
-static gchar *
-scroll_method_name (void)
-{
-  if (view_scroll_method==atari_scroll)
-    return "atari_scroll";
-  if (view_scroll_method==smooth_scroll)
-    return "smooth_scroll";
-  if (view_scroll_method==center_scroll)
-    return "center_scroll";
- 
-  return "default";
-
-}
-
-static void
-set_scroll_method (gchar *name)
-{
-
-  if (!strcmp (name,"atari_scroll"))
-    view_scroll_method = atari_scroll;
-  if (!strcmp (name,"smooth_scroll"))
-    view_scroll_method = smooth_scroll;
-  if (!strcmp (name,"center_scroll"))
-    view_scroll_method = center_scroll;
-
-}
-
-
-
 
 /*****************************************************************************/
 /* Save preferences.  */
 
-void
-gconf_set_scroll_method (gchar *value)
-{
-  gconf_client_set_string (get_gconf_client (), KEY_SCROLL_METHOD,
-                           value, NULL);
-}
-
 void
 gconf_set_game_name (gchar *value)
 {
@@ -345,8 +297,6 @@ preferences_save (gboolean global)
   gconf_set_joystick_switch_level (joystick_switch_level);
 #endif  
 
-  gconf_set_scroll_method (scroll_method_name ());
-
   if (game)
     {
       gconf_set_game_name (game->filename);
@@ -395,8 +345,6 @@ preferences_restore (void)
 {
   char        *filename;
   gboolean     def;
-  guint        cave;
-  gchar       *scroll_method;
   GtkWidget * dialog;
   
 #if 0
@@ -434,23 +382,16 @@ preferences_restore (void)
   
   set_sound_enabled (pref_get_sound_enabled ());
 
-  scroll_method = gconf_client_get_string (get_gconf_client (),
-                                           KEY_SCROLL_METHOD, NULL);
-  if (scroll_method == NULL)
-    scroll_method = g_strdup ("atari_scroll");
-  set_scroll_method (scroll_method);
-  g_free (scroll_method);
-
   filename = gconf_client_get_string (get_gconf_client (),
                                       KEY_GAME_NAME, NULL);
   def = (filename == NULL);
 
-  cave = gconf_client_get_int (get_gconf_client (),
-                               KEY_START_CAVE, NULL);
+  start_cave = gconf_client_get_int (get_gconf_client (),
+				     KEY_START_CAVE, NULL);
 
   if (!default_game || !load_game_by_name (default_game, 0))
     {
-      if (def || !load_game_by_name (filename, cave))
+      if (def || !load_game_by_name (filename, start_cave))
 	{
 	  if (!load_game_by_name (CAVESDIR"/default.caves", 0)) {
             dialog = gtk_message_dialog_new (GTK_WINDOW (app),
@@ -495,10 +436,7 @@ struct _PreferencesData
 
 
   /* Page three */
-
-  /* Page four */
-  gchar            *scroll_method_name;
-
+  /* FIXME: Sounds temporarily disabled.*/
 };
 
 
@@ -579,18 +517,7 @@ preferences_set_joystick_switch_level (GtkAdjustment *adjust, gpointer data)
 
 
 
-/* The scroll method callbacks.  */
-
-static void
-preferences_set_scroll_method (GtkWidget *widget, gpointer data)
-{
-  gchar * names[3] = { "atari_scroll", "smooth_scroll", "center_scroll" };
-  
-  set_scroll_method (names[gtk_combo_box_get_active (GTK_COMBO_BOX (widget))]);
-  gconf_set_scroll_method (scroll_method_name ());
-}
-
-
+#if 0
 static void
 enable_sound_callback (GtkWidget *widget, gpointer *data)
 {
@@ -601,7 +528,7 @@ enable_sound_callback (GtkWidget *widget, gpointer *data)
   set_sound_enabled (is_on);
   gconf_set_sound_enabled (is_on);
 }
-
+#endif
 
 static GtkWidget *
 preferences_dialog_new (void)
@@ -612,9 +539,13 @@ preferences_dialog_new (void)
   GtkWidget *list_view;
   GtkWidget *label;
   GtkWidget *scrolled;
+#if 0
   GtkWidget *frame;
   GtkWidget *fv;
+#endif
+#if 0
   GtkWidget *enable_sound_toggle_button;
+#endif
   GtkListStore *list;
   GtkTreeIter iter;
   GtkTreeSelection *selection;
@@ -631,14 +562,17 @@ preferences_dialog_new (void)
                                             GTK_STOCK_CLOSE,
                                             GTK_RESPONSE_ACCEPT,
                                             NULL);
+  gtk_container_set_border_width (GTK_CONTAINER (properties), 5);
+  gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (properties)->vbox), 2);
   gtk_dialog_set_has_separator (GTK_DIALOG (properties), FALSE);  
   notebook = gtk_notebook_new ();
+  gtk_container_set_border_width (GTK_CONTAINER (notebook), 5);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (properties)->vbox), notebook, 
                       TRUE, TRUE, 0);
   
   /* The first page of our preferences dialog. */
-  box= gtk_vbox_new (FALSE, GNOME_PAD);
-  gtk_container_set_border_width (GTK_CONTAINER (box), GNOME_PAD_SMALL);
+  box= gtk_vbox_new (FALSE, 6);
+  gtk_container_set_border_width (GTK_CONTAINER (box), 12);
 
   /* The list of game names.  */
   list= gtk_list_store_new (N_COLS, 
@@ -675,7 +609,7 @@ preferences_dialog_new (void)
   prdata->game_list= list_view;
 
   renderer = gtk_cell_renderer_text_new ();
-  column = gtk_tree_view_column_new_with_attributes (_("Game title"), 
+  column = gtk_tree_view_column_new_with_attributes (_("Game Title"), 
                                                      renderer, 
                                                      "text", 0, 
                                                      NULL);
@@ -696,12 +630,15 @@ preferences_dialog_new (void)
   */
 
   scrolled = gtk_scrolled_window_new (NULL, NULL);
+  gtk_widget_set_size_request (scrolled, 250, 200);
+  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled),
+                                       GTK_SHADOW_ETCHED_IN);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled),
-                                  GTK_POLICY_ALWAYS,
+                                  GTK_POLICY_AUTOMATIC,
                                   GTK_POLICY_AUTOMATIC);
 
   gtk_container_add (GTK_CONTAINER (scrolled), list_view);
-  gtk_box_pack_start (GTK_BOX (box), scrolled, TRUE, TRUE, GNOME_PAD_SMALL);
+  gtk_box_pack_start (GTK_BOX (box), scrolled, TRUE, TRUE, 0);
 
   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (list_view));
   gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
@@ -737,7 +674,7 @@ preferences_dialog_new (void)
                      GTK_SIGNAL_FUNC (game_selector_select_row),
                      prdata);
 
-  label= gtk_label_new_with_mnemonic (_("_Game"));
+  label= gtk_label_new (_("Game"));
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook), 
 			    box, label);
 
@@ -746,8 +683,8 @@ preferences_dialog_new (void)
   prdata->joystick_deviceid    = joystick_deviceid;
   prdata->joystick_switch_level= joystick_switch_level;
 
-  box= gtk_vbox_new (FALSE, GNOME_PAD);
-  gtk_container_set_border_width (GTK_CONTAINER (box), GNOME_PAD_SMALL);
+  box= gtk_vbox_new (FALSE, 18);
+  gtk_container_set_border_width (GTK_CONTAINER (box), 12);
   
   {
     GtkObject *adjust;
@@ -760,21 +697,22 @@ preferences_dialog_new (void)
     GList     *devices;
 #endif
     frame= games_frame_new (_("Device"));
-    gtk_box_pack_start (GTK_BOX (box), frame, FALSE, FALSE, GNOME_PAD_SMALL);
+    gtk_box_pack_start (GTK_BOX (box), frame, FALSE, FALSE, 0);
 
-    vbox= gtk_vbox_new (FALSE, GNOME_PAD);
+    vbox= gtk_vbox_new (FALSE, 6);
     gtk_container_add (GTK_CONTAINER (frame), vbox);
 
-    hbox= gtk_hbox_new (FALSE, GNOME_PAD);
-    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, GNOME_PAD_SMALL);
+    hbox= gtk_hbox_new (FALSE, 12);
+    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
-    label= gtk_label_new (_("Joystick device:"));
-    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, GNOME_PAD_SMALL);
+    label= gtk_label_new_with_mnemonic (_("_Joystick device:"));
+    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
     optionmenu= gtk_combo_box_new_text ();    
+    gtk_label_set_mnemonic_widget (GTK_LABEL (label), optionmenu);
 
     /* We definatly have a "disable" entry.  */
-    gtk_combo_box_append_text (GTK_COMBO_BOX (optionmenu), _("disabled"));
+    gtk_combo_box_append_text (GTK_COMBO_BOX (optionmenu), _("Disabled"));
 
 #if 0
     g_signal_connect (GTK_OBJECT (menuitem), "activate",
@@ -803,19 +741,19 @@ preferences_dialog_new (void)
 	  gtk_menu_set_active (GTK_MENU (device_menu), i);
       }
 #endif    
-    gtk_box_pack_start (GTK_BOX (hbox), optionmenu, FALSE, FALSE, 2);
+    gtk_box_pack_start (GTK_BOX (hbox), optionmenu, TRUE, TRUE, 0);
 
-    frame= games_frame_new (_("Digital joystick emulation"));
-    gtk_box_pack_start (GTK_BOX (box), frame, FALSE, FALSE, GNOME_PAD_SMALL);
+    frame= games_frame_new (_("Digital Joystick Emulation"));
+    gtk_box_pack_start (GTK_BOX (box), frame, FALSE, FALSE, 0);
 
-    vbox= gtk_vbox_new (FALSE, GNOME_PAD);
+    vbox= gtk_vbox_new (FALSE, 6);
     gtk_container_add (GTK_CONTAINER (frame), vbox);
 
-    hbox= gtk_hbox_new (FALSE, GNOME_PAD);
-    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, GNOME_PAD_SMALL);
+    hbox= gtk_hbox_new (FALSE, 12);
+    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
-    label= gtk_label_new (_("Switch level:"));
-    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, GNOME_PAD_SMALL);
+    label= gtk_label_new_with_mnemonic (_("_Switch level:"));
+    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
     adjust= gtk_adjustment_new (prdata->joystick_switch_level,
 				0.0, 1.0, 0.02, 0.1, 0.0);
@@ -825,8 +763,9 @@ preferences_dialog_new (void)
 			NULL);
     
     scale= gtk_hscale_new (GTK_ADJUSTMENT (adjust));
+    gtk_label_set_mnemonic_widget (GTK_LABEL (label), scale);
     gtk_scale_set_digits (GTK_SCALE (scale), 2);
-    gtk_box_pack_start (GTK_BOX (hbox), scale, TRUE, TRUE, GNOME_PAD_SMALL);
+    gtk_box_pack_start (GTK_BOX (hbox), scale, TRUE, TRUE, 0);
 #if 0    
     if (prdata->joystick_deviceid == GDK_CORE_POINTER)
       {
@@ -837,16 +776,16 @@ preferences_dialog_new (void)
   }
   
 
-  label= gtk_label_new_with_mnemonic (_("_Joystick"));
+  label= gtk_label_new (_("Joystick"));
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook), 
 			    box, label);
 
   /* The third page of our preferences dialog. */
 
-  box = gtk_vbox_new (FALSE, GNOME_PAD);
-  gtk_container_set_border_width (GTK_CONTAINER (box), GNOME_PAD_SMALL);
+  box = gtk_vbox_new (FALSE, 18);
+  gtk_container_set_border_width (GTK_CONTAINER (box), 12);
   
-
+#if 0
   frame = games_frame_new (_("Sound"));
   fv = gtk_vbox_new (FALSE, FALSE);
   gtk_box_set_spacing (GTK_BOX (fv), 6);
@@ -866,69 +805,12 @@ preferences_dialog_new (void)
                     G_CALLBACK (enable_sound_callback), NULL);
   
   gtk_container_add (GTK_CONTAINER(fv), enable_sound_toggle_button);
-  
+
   label = gtk_label_new_with_mnemonic (_("_Sound"));
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook),
 			    box, label);
 
-
-  /* Fourth page is miscellaneous stuff */
-  
-  box= gtk_vbox_new (FALSE, GNOME_PAD);
-  gtk_container_set_border_width (GTK_CONTAINER (box), GNOME_PAD_SMALL);
-  
-
-  
-  {
-    GtkWidget *frame;
-    GtkWidget *hbox;
-    GtkWidget *vbox;
-    GtkWidget *optionmenu;
-
-
-    frame= games_frame_new (_("Scroll method"));
-    gtk_box_pack_start (GTK_BOX (box), frame, FALSE, FALSE, GNOME_PAD_SMALL);
-
-    vbox= gtk_vbox_new (FALSE, GNOME_PAD);
-    gtk_container_add (GTK_CONTAINER (frame), vbox);
-
-    hbox= gtk_hbox_new (FALSE, GNOME_PAD);
-    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, GNOME_PAD_SMALL);
-
-    /*
-    label= gtk_label_new (_("Scroll method:"));
-    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, GNOME_PAD_SMALL);
-    */
-
-    optionmenu= gtk_combo_box_new_text ();
-    
-
-    prdata->scroll_method_name = scroll_method_name();
-
-    gtk_combo_box_append_text (GTK_COMBO_BOX (optionmenu),
-                               _("Atari like scrolling"));
-    if (!strcmp(prdata->scroll_method_name,"atari_scroll"))
-      gtk_combo_box_set_active (GTK_COMBO_BOX (optionmenu), 0);
-    gtk_combo_box_append_text (GTK_COMBO_BOX (optionmenu),
-                               _("Smooth scrolling"));
-    if (!strcmp(prdata->scroll_method_name,"smooth_scroll"))
-      gtk_combo_box_set_active (GTK_COMBO_BOX (optionmenu), 1);
-    gtk_combo_box_append_text (GTK_COMBO_BOX (optionmenu),
-                               _("Always in the center"));
-    if (!strcmp(prdata->scroll_method_name,"center_scroll"))
-      gtk_combo_box_set_active (GTK_COMBO_BOX (optionmenu), 2);
-    
-    
-    g_signal_connect (GTK_OBJECT (optionmenu), "changed",
-			(GtkSignalFunc) preferences_set_scroll_method,
-			NULL);
-   
-    gtk_box_pack_start (GTK_BOX (hbox), optionmenu, FALSE, FALSE, 2);
-  }
-
-  label = gtk_label_new_with_mnemonic (_("_Misc."));
-  gtk_notebook_append_page (GTK_NOTEBOOK (notebook),
-			    box, label);
+#endif  
 
   gtk_widget_show_all (notebook);
 
