@@ -2,7 +2,7 @@
 
 /* gnome-stones - sound.c
  *
- * Time-stamp: <2003/06/19 16:11:28 mccannwj>
+ * Time-stamp: <2004/07/18 16:06:47 callum>
  *
  * Copyright (C) 2001 Michal Benes
  *
@@ -20,10 +20,15 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <esd.h>
+#ifndef NO_ESD
+# include <esd.h>
+#endif
 #include <gnome.h>
 #include "sound.h"
 
+/* Effectively disable all sound until we canfind replacement samples. */
+#define NO_ESD
+
 gboolean sound_enabled = TRUE;
 
 gint title_music = -1;
