@@ -76,6 +76,7 @@ enum {
 enum {
 	NO_ACTION,
 	SHOW_ACTION,
+	MAYBE_SHOW_ACTION,
 	CLEAR_ACTION,
 	FLAG_ACTION
 };
@@ -85,7 +86,7 @@ static gint minefield_signals[LAST_SIGNAL];
 static GtkWidgetClass *parent_class;
 
 /*  Prototypes */
-G_INLINE_FUNC gint cell_idx_no_checks(GtkMineField *mfield, guint x, guint y);
+static inline gint cell_idx_no_checks(GtkMineField *mfield, guint x, guint y);
 static gint cell_idx(GtkMineField *mfield, guint x, guint y);
 static void setup_sign (sign *signp, const char *file, guint minesize);
 static void gtk_mine_draw(GtkMineField *mfield, guint x, guint y);
@@ -115,7 +116,7 @@ static void gtk_minefield_multi_press(GtkMineField *mfield, guint x, guint y, gi
 /* The abstraction of the coordinate system. Note that this is inline
    code that does no checking, use it sparsely. If in doubt, use
    cell_idx instead. */
-G_INLINE_FUNC gint cell_idx_no_checks (GtkMineField *mfield, guint x, guint y)
+static inline gint cell_idx_no_checks (GtkMineField *mfield, guint x, guint y)
 {
 	return x+y*mfield->xsize;
 }
@@ -828,6 +829,8 @@ static void gtk_minefield_multi_release (GtkMineField *mfield, guint x, guint y,
         gint n, nx, ny, i, c2;
 	guint lose = 0;
 
+	g_return_if_fail (c > 0);
+
         mfield->multi_mode = 0;
 
         n = 0;
@@ -898,8 +901,7 @@ static gint gtk_minefield_motion_notify(GtkWidget *widget, GdkEventMotion *event
                         mfield->mines[mfield->cdown].down = 0;
                         gtk_mine_draw(mfield, mfield->cdownx, mfield->cdowny);
 
-                        multi = mfield->multi_mode;
-			if (multi)
+			if (mfield->multi_mode)
 				gtk_minefield_multi_release(mfield, mfield->cdownx,
 				                            mfield->cdowny,
 				                            mfield->cdown, 0);
@@ -909,6 +911,9 @@ static gint gtk_minefield_motion_notify(GtkWidget *widget, GdkEventMotion *event
                         mfield->mines[c].down = 1;
                         gtk_mine_draw(mfield, x, y);
 
+			multi = (mfield->action == MAYBE_SHOW_ACTION) && 
+				mfield->mines[c].shown;
+
 			if (multi)
 				gtk_minefield_multi_press(mfield, x, y, c);
                 }
@@ -966,10 +971,9 @@ static gint gtk_minefield_button_press(GtkWidget *widget, GdkEventButton *event)
 		 * about all the extra legacy crap. */
 		switch (event->button) {
 		case 1:
-			mfield->action = SHOW_ACTION;
+			mfield->action = MAYBE_SHOW_ACTION;
 			if ((event->state & GDK_SHIFT_MASK) ||
-			    (mfield->bdown[2]) ||
-			    mfield->mines[c].shown)
+			    (mfield->bdown[2]))
 				mfield->action = CLEAR_ACTION;
 			break;
 		case 2:
@@ -984,7 +988,9 @@ static gint gtk_minefield_button_press(GtkWidget *widget, GdkEventButton *event)
 
 		/* Now actually do the actions. Most of the real work
 		 * is done in the button_release handler. */
-		if (mfield->action == CLEAR_ACTION) {
+		if ((mfield->action == CLEAR_ACTION) || 
+		    ((mfield->action == MAYBE_SHOW_ACTION) &&
+		     mfield->mines[c].shown)) {
                         gtk_minefield_multi_press(mfield, x, y, c);
                 }
                 else if (mfield->action == FLAG_ACTION && mfield->bdown[2] == 1)
@@ -1013,6 +1019,10 @@ static gint gtk_minefield_button_release(GtkWidget *widget, GdkEventButton *even
 
 	if (mfield->lose || mfield->win) return FALSE;
 
+	if (mfield->action == MAYBE_SHOW_ACTION)
+		mfield->action = mfield->mines[mfield->cdown].shown ? 
+			CLEAR_ACTION : SHOW_ACTION;
+
         if (event->button <= 3 && mfield->bdown[event->button-1]) {
                 switch (mfield->action) {
                 case SHOW_ACTION:
@@ -1028,7 +1038,6 @@ static gint gtk_minefield_button_release(GtkWidget *widget, GdkEventButton *even
 					0, NULL);
 		}
 		mfield->mines[mfield->cdown].down = 0;
-                mfield->cdown = -1;
 		mfield->action = NO_ACTION;
 		mfield->bdown[event->button-1] = 0;
 		gtk_mine_draw(mfield, mfield->cdownx, mfield->cdowny);
